==> localnews-spider-sync-model-1.0.2.2-sources.jar: com/bxm/localnews/sync/vo/spider/IDataVideo.java <==
package com.bxm.localnews.sync.vo.spider;

import java.util.List;

/**
 * @author zhaoyadong 2018/12/11 22:28
 * @desc
 */
public class IDataVideo extends BaseSyncBean {

    /**
     * redis中的id
     */
    private String id;

    /**
     * 同步的视频id
     */
    private String videoId;

    /**
     * 发布者id
     */
    private String posterId;

    /**
     * 发布者昵称
     */
    private String posterScreenName;

    /**
     * 发布时间
     */
    private String publishDateStr;

    /**
     * 视频标题
     */
    private String title;

    /**
     * 发布时间
     */
    private Long publishDate;

    /**
     * 视频源列表
     */
    private List<String> videoUrls;

    /**
     * 封面地址
     */
    private String coverUrl;

    /**
     * 视频描述
     */
    private String description;

    /**
     * 时长（/分钟）
     */
    private Long durationMin;

    /**
     * 点赞数
     */
    private Long likeCount;

    /**
     * 分享次数
     */
    private Long shareCount;

    /**
     * 评论次数
     */
    private Long commentCount;

    /**
     * 观看次数
     */
    private Long viewCount;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getVideoId() {
        return videoId;
    }

    public void setVideoId(String videoId) {
        this.videoId = videoId;
    }

    public String getPosterId() {
        return posterId;
    }

    public void setPosterId(String posterId) {
        this.posterId = posterId;
    }

    public String getPosterScreenName() {
        return posterScreenName;
    }

    public void setPosterScreenName(String posterScreenName) {
        this.posterScreenName = posterScreenName;
    }

    public String getPublishDateStr() {
        return publishDateStr;
    }

    public void setPublishDateStr(String publishDateStr) {
        this.publishDateStr = publishDateStr;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getPublishDate() {
        return publishDate;
    }

    public void setPublishDate(Long publishDate) {
        this.publishDate = publishDate;
    }

    public List<String> getVideoUrls() {
        return videoUrls;
    }

    public void setVideoUrls(List<String> videoUrls) {
        this.videoUrls = videoUrls;
    }

    public String getCoverUrl() {
        return coverUrl;
    }

    public void setCoverUrl(String coverUrl) {
        this.coverUrl = coverUrl;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getDurationMin() {
        return durationMin;
    }

    public void setDurationMin(Long durationMin) {
        this.durationMin = durationMin;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

    public Long getShareCount() {
        return shareCount;
    }

    public void setShareCount(Long shareCount) {
        this.shareCount = shareCount;
    }

    public Long getCommentCount() {
        return commentCount;
    }

    public void setCommentCount(Long commentCount) {
        this.commentCount = commentCount;
    }

    public Long getViewCount() {
        return viewCount;
    }

    public void setViewCount(Long viewCount) {
        this.viewCount = viewCount;
    }
}

==> localnews-spider-sync-model-1.0.13.1-20191024.063343-1-sources.jar: com/bxm/localnews/sync/vo/spider/IDataVideo.java <==
package com.bxm.localnews.sync.vo.spider;

import java.util.List;

/**
 * @author zhaoyadong 2018/12/11 22:28
 * @desc
 */
@Deprecated
public class IDataVideo extends BaseSyncBean {

    /**
     * redis中的id
     */
    private String id;

    /**
     * 同步的视频id
     */
    private String videoId;

    /**
     * 发布者id
     */
    private String posterId;

    /**
     * 发布者昵称
     */
    private String posterScreenName;

    /**
     * 发布时间
     */
    private String publishDateStr;

    /**
     * 视频标题
     */
    private String title;

    /**
     * 发布时间
     */
    private Long publishDate;

    /**
     * 视频源列表
     */
    private List<String> videoUrls;

    /**
     * 封面地址
     */
    private String coverUrl;

    /**
     * 视频描述
     */
    private String description;

    /**
     * 时长（/分钟）
     */
    private Long durationMin;

    /**
     * 点赞数
     */
    private Long likeCount;

    /**
     * 分享次数
     */
    private Long shareCount;

    /**
     * 评论次数
     */
    private Long commentCount;

    /**
     * 观看次数
     */
    private Long viewCount;

    /**
     * 长宽高占比
     */
    private Double widthRatio;

    public Double getWidthRatio() {
        return widthRatio;
    }

    public void setWidthRatio(Double widthRatio) {
        this.widthRatio = widthRatio;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getVideoId() {
        return videoId;
    }

    public void setVideoId(String videoId) {
        this.videoId = videoId;
    }

    public String getPosterId() {
        return posterId;
    }

    public void setPosterId(String posterId) {
        this.posterId = posterId;
    }

    public String getPosterScreenName() {
        return posterScreenName;
    }

    public void setPosterScreenName(String posterScreenName) {
        this.posterScreenName = posterScreenName;
    }

    public String getPublishDateStr() {
        return publishDateStr;
    }

    public void setPublishDateStr(String publishDateStr) {
        this.publishDateStr = publishDateStr;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Long getPublishDate() {
        return publishDate;
    }

    public void setPublishDate(Long publishDate) {
        this.publishDate = publishDate;
    }

    public List<String> getVideoUrls() {
        return videoUrls;
    }

    public void setVideoUrls(List<String> videoUrls) {
        this.videoUrls = videoUrls;
    }

    public String getCoverUrl() {
        return coverUrl;
    }

    public void setCoverUrl(String coverUrl) {
        this.coverUrl = coverUrl;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getDurationMin() {
        return durationMin;
    }

    public void setDurationMin(Long durationMin) {
        this.durationMin = durationMin;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

    public Long getShareCount() {
        return shareCount;
    }

    public void setShareCount(Long shareCount) {
        this.shareCount = shareCount;
    }

    public Long getCommentCount() {
        return commentCount;
    }

    public void setCommentCount(Long commentCount) {
        this.commentCount = commentCount;
    }

    public Long getViewCount() {
        return viewCount;
    }

    public void setViewCount(Long viewCount) {
        this.viewCount = viewCount;
    }
}
